@@ -1,8 +1,24 @@
+# Licensed to the Apache Software Foundation (ASF) under one or more
+# contributor license agreements.  See the NOTICE file distributed with
+# this work for additional information regarding copyright ownership.
+# The ASF licenses this file to You under the Apache License, Version 2.0
+# (the "License"); you may not use this file except in compliance with
+# the License.  You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+
 package Apache::TestMB;
 
 use strict;
 use vars qw(@ISA);
-use Module::Build;
+use Module::Build 0.18;
 use Apache::Test ();
 use Apache::TestConfig ();
 @ISA = qw(Module::Build);
@@ -242,7 +258,7 @@ complete. Note that C<Build.PL> can be called C<Apache::Test>-specific
 options in addition to the usual C<Module::Build> options. For
 example:
 
-  perl Build.PL -apxs=/usr/local/apache/bin/apxs
+  perl Build.PL -apxs /usr/local/apache/bin/apxs
 
 Consult the L<Apache::Test|Apache::Test> documentation for a complete
 list of options.
